.. _api_ref:

*******************************
OS-Ken API Reference
*******************************

.. XXX list all members explicitly to workaround a sphinx bug
.. XXX https://bitbucket.org/birkenfeld/sphinx/issue/1362

.. py:currentmodule:: os_ken.base.app_manager
.. autoclass:: os_ken.base.app_manager.OSKenApp
   :members: OFP_VERSIONS,_CONTEXTS,_EVENTS,close,context_iteritems,reply_to_request,send_event,send_event_to_observers,send_request,start

.. autoclass:: os_ken.controller.dpset.DPSet
   :members:
